rounding.risk.s.thresholds.RdCompute thresholds for the significant s of the reported standard deviation such that we can rule-out the errors: misclassification, wrong inclusion, wrong exclusion
rounding.risk.s.thresholds(z, z0 = z0, h = 0.2)
| z | a vector of z statistics |
|---|---|
| z0 | significance threshold. Can be a single number or a vector of length z |
| h | half-width of considered window around z0 |
A data frame with the columns "z", "s.misclass", "s.include", "s.exclude" specifying for each z value the corresponding thresholds.