The significand is the integer of all significand digits, e.g. the significand of 0.012 is 12.

significand(x, num.deci = NULL)

Arguments

x

a numeric vector.

num.deci

If not NULL a vector that states the number reported decimal places for x. This can be used if we know that there were addtional trailing zeros.