make.z.pdf.RdThe PDF is normalized such that the point of highest density is 1
make.z.pdf( z, bw = 0.05, kernel = "gaussian", n = 512, dat, min.s = 100, z.min = 0, z.max = 5, show.hist = FALSE, ... )
| z | a vector of z statistics. Usually, you would select all values from dat whose mu and sigma have sufficiently many significant digits |
|---|---|
| ... | other parameters passed to |