sample.uniform.z.deround.RdSample derounded z from the uniformely derounded distributon for a given single value of mu and sigma
sample.uniform.z.deround( n, mu, sigma, mu.dec = pmax(num.deci(mu), num.deci(sigma)), sigma.dec = mu.dec )
| n | Number of sample draws |
|---|---|
| mu | Reported coefficient, possibly rounded |
| sigma | Reported standard error, possibly rounded. |
| mu.dec | Number of decimal places mu is reported to. Usually, we would assume that mu and sigma are rounded to the same number of decimal places. Since trailing zeros may not be detected, we set the default |
| sigma.dec | By default equal to mu.dec. |